var initPrefersColorScheme = (function () {
	'use strict';

	var colorIndexRegExp = /((?:not )?all and )?(\(color-index:\s*(22|48|70)\))/i;

	var prefersColorSchemeInit = function prefersColorSchemeInit(initialColorScheme) {
	  var mediaQueryString = '(prefers-color-scheme: dark)';
	  var mediaQueryList = window.matchMedia && matchMedia(mediaQueryString);
	  var hasNativeSupport = mediaQueryList && mediaQueryList.media === mediaQueryString;

	  var mediaQueryListener = function mediaQueryListener() {
	    set(mediaQueryList.matches ? 'dark' : 'light');
	  };

	  var removeListener = function removeListener() {
	    if (mediaQueryList) {
	      mediaQueryList.removeListener(mediaQueryListener);
	    }
	  };

	  var set = function set(colorScheme) {
	    if (colorScheme !== currentColorScheme) {
	      currentColorScheme = colorScheme;

	      if (typeof result.onChange === 'function') {
	        result.onChange();
	      }
	    }

	    [].forEach.call(document.styleSheets, function (styleSheet) {
	      [].forEach.call(styleSheet.cssRules, function (cssRule) {
	        var mediaMatch = (Object(cssRule.media).mediaText || '').match(colorIndexRegExp);

	        if (mediaMatch) {
	          cssRule.media.mediaText = ((/^dark$/i.test(colorScheme) ? mediaMatch[3] === '48' : /^light$/i.test(colorScheme) ? mediaMatch[3] === '70' : mediaMatch[3] === '22') ? 'not all and ' : '') + cssRule.media.mediaText.replace(colorIndexRegExp, '$2');
	        }
	      });
	    });
	  };

	  var result = Object.defineProperty({
	    hasNativeSupport: hasNativeSupport,
	    removeListener: removeListener
	  }, 'scheme', {
	    get: function get() {
	      return currentColorScheme;
	    },
	    set: set
	  }); // initialize the color scheme using the provided value, the system value, or light

	  var currentColorScheme = initialColorScheme || (mediaQueryList && mediaQueryList.matches ? 'dark' : 'light');
	  set(currentColorScheme); // listen for system changes

	  if (mediaQueryList) {
	    mediaQueryList.addListener(mediaQueryListener);
	  }

	  return result;
	};

	return prefersColorSchemeInit;

}());
//# sourceMappingURL=browser.js.map
